@@ -34,10 +34,10 @@ class PrinterDelegate: public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    explicit PrinterDelegate(QObject *parent = 0);
+    explicit PrinterDelegate(QObject *parent = nullptr);
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 private:
     int m_favIconSize;
